@@ -1,12 +1,14 @@
 #' Observed Run-Off Triangle Layout vs. Predicted (Unknown) Layout
 #'
-#' Simple layout function to make work with (cumulative or incremental) run-off 
-#' triangles more easy and straightforward.   
+#' Simple layout function to  allow work with fully developed run-off triangles 
+#' (i.e., completed squares that also contain typically unknown (future) claim 
+#' payments). Such data are not common in actuarial practice but 
+#' they are usefull for retrospective analysis and back-testing purposes.  
 #'
 #' @param object either an integer value to denote the dimension of the run-off 
 #' triangle layout (i.e., the value that represents the number of origins (rows) 
 #' and also the number of the development periods (columns)). Alternatively, 
-#' a cumulatige or incremental run-off triangle (i.e, an object of the class 
+#' a cumulative or incremental run-off triangle (i.e, an object of the class 
 #' \code{matrix} or \code{triangle}) can be provided in \code{object}. In such 
 #' case the output returns the standard run-off triangle with \code{NA} values 
 #' in the lower-right triangular part of the matrix (regardless of wheter the
@@ -28,12 +30,15 @@
 #' @seealso [plot.profileLadder()], [parallelReserve()], [mcReserve()]
 #' 
 #' @examples
+#' ## observed/unobserved layout for the run-off triangle with 5 origins
 #' print(observed(5))
 #' print(!observed(5))
 #' 
-#' data(CameronMutual)
-#' observed(CameronMutual)
-#' observed(CameronMutual, cum = FALSE)
+#' ## fully observed run-off triangle with typically unknown (future) payments
+#' ## included in the lower-right triangular part for evaluation purposes
+#' data(CameronMutual) ## the full data matrix
+#' observed(CameronMutual) ## cummulative run-off triangle
+#' observed(CameronMutual, cum = FALSE) ## incremental run-off triangle
 #' 
 #' @export
 observed <- function(object, cum = TRUE){
@@ -46,7 +51,7 @@ observed <- function(object, cum = TRUE){
     return(layout)
   } else {
     if (inherits(object, "profileLadder")){
-      chainLadder <- object$inputTriangle
+      chainLadder <- object$Triangle
       chainLadder[row(chainLadder) + col(chainLadder) > nrow(chainLadder) + 1] <- NA
       return(as.profileLadder(chainLadder))
     } else {
@@ -54,9 +59,9 @@ observed <- function(object, cum = TRUE){
         stop("Incorrect input value of 'object' provided")}
       if (dim(object)[1] != dim(object)[2]){
         stop("The dimensions of the imput object do not correspond.")}
-      if (cum != TRUE & cum != FALSE){
+      if (!is.logical(cum)){
         stop("Parameter 'cum' must be logical (TRUE/FALSE)")}
-      if (cum == TRUE){### return cumulative triangle
+      if (cum){### return cumulative triangle
         if (sum(object[,1]) > sum(object[row(object) + col(object) == nrow(object) + 1])){
           ### object is incremental triangle
           object <- ChainLadder::incr2cum(object)
@@ -68,7 +73,7 @@ observed <- function(object, cum = TRUE){
           return(object)
         }
       }
-      if (cum == FALSE){### return incremental triangle
+      if (!cum){### return incremental triangle
         if (sum(object[,1]) > sum(object[row(object) + col(object) == nrow(object) + 1])){
           ### object is incremental triangle
           object[row(object) + col(object) > nrow(object) + 1] <- NA
